@@ -14,7 +14,7 @@
 # limitations under the License.
 
 """
-The By implemention.
+The By implementation.
 """
 
 class By(object):
@@ -30,3 +30,10 @@ class By(object):
     TAG_NAME = "tag name"
     CLASS_NAME = "class name"
     CSS_SELECTOR = "css selector"
+
+    @classmethod
+    def is_valid(cls, by):
+        for attr in dir(cls):
+            if by == getattr(cls, attr):
+                return True
+        return False
